# -*- coding: utf-8 -*-

from datetime import datetime
import os

from apiclient.discovery import build
from httplib2 import Http
import oauth2client
from oauth2client import client
from oauth2client import tools

import serial
import unicodedata

import funk_analize
import funk_mjeseci
import vrijeme
import ucitaj_serial

try:
    import argparse
    flags = argparse.ArgumentParser(parents=[tools.argparser]).parse_args()
except ImportError:
    flags = None

SCOPES = 'https://www.googleapis.com/auth/calendar.readonly'
CLIENT_SECRET_FILE = 'client_secret.json'
APPLICATION_NAME = 'Google Calendar API Quickstart'

def get_credentials():
    """Gets valid user credentials from storage.

    If nothing has been stored, or if the stored credentials are invalid,
    the OAuth2 flow is completed to obtain the new credentials.

    Returns:
        Credentials, the obtained credential.
    """
    home_dir = os.path.expanduser('~')
    credential_dir = os.path.join(home_dir, '.credentials')
    if not os.path.exists(credential_dir):
        os.makedirs(credential_dir)
    credential_path = os.path.join(credential_dir,
                                   'calendar-quickstart.json')

    store = oauth2client.file.Storage(credential_path)
    credentials = store.get()
    if not credentials or credentials.invalid:
        flow = client.flow_from_clientsecrets(CLIENT_SECRET_FILE, SCOPES)
        flow.user_agent = APPLICATION_NAME
        if flags:
            credentials = tools.run_flow(flow, store, flags)
        else: # Needed only for compatability with Python 2.6
            credentials = tools.run(flow, store)
        print 'Storing credentials to ' + credential_path
    return credentials

def initialize():
    credentials = get_credentials()
    service = build('calendar', 'v3', http=credentials.authorize(Http()))

    return credentials, service

credentials, service = initialize()

def example_event(linija, pocetak, kraj):
    event = {
      'summary': 'Podsjetnik',
      'description': linija,
      'start': {
        'dateTime': pocetak,
        'timeZone': 'Europe/Zagreb',
      },
      'end': {
        'dateTime': kraj,
        'timeZone': 'Europe/Zagreb',
      },
     
      'reminders': {
        'useDefault': False,
        'overrides': [
          {'method': 'email', 'minutes': 24 * 60},
        ],
      },
    }

    return event

def event_put(event, calendar_name, service):
    return service.events().insert(calendarId=calendar_name, body=event).execute()

def upcoming_events(event_count):
    now = datetime.utcnow().isoformat() + 'Z' # 'Z' indicates UTC time
    print 'Getting the upcoming event_cnt events'
    eventsResult = service.events().list(
       calendarId='primary', timeMin=now, maxResults=event_count, singleEvents=True,
       orderBy='startTime').execute()
    events = eventsResult.get('items', [])

    if not events:
       print 'No upcoming events found.'
    for event in events:
       start = event['start'].get('dateTime', event['start'].get('date'))
       print start, event['summary'].encode('utf-8')

def main():
  arduino = serial.Serial( 9, 9600, timeout=.1)

  while True:
    data = arduino.readline()#[:-2] #the last bit gets rid of the new-line chars
    if data:
      data = unicode(data, 'utf-8')
      data = unicodedata.normalize('NFKD', data).encode('ascii','ignore')
      print data
      dan, mjesec, sati = funk_analize.analiza(data)
      if dan != '0' and mjesec != '0':
        pocetak, kraj = vrijeme.vrime(dan, mjesec, sati)
        barbara_event = example_event(data, pocetak, kraj)
        event = event_put(barbara_event, 'primary', service)
        print 'Event created: %s' % (event.get('htmlLink'))
      else:
        print 'Podsjetnik se ne moze izdraditi!'
  arduino.close() 

if __name__ == '__main__':
    main()
